@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2008, 2009, 2012 Rolf Eike Beer <kde@opensource.sf-tec.de>
+    SPDX-FileCopyrightText: 2008-2022 Rolf Eike Beer <kde@opensource.sf-tec.de>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -21,8 +21,8 @@ class KGpgChangeTrust: public KGpgEditKeyTransaction {
 
 	Q_DISABLE_COPY(KGpgChangeTrust)
 public:
-    explicit KGpgChangeTrust(QObject *parent, const QString &keyid, const gpgme_validity_t trust);
-    ~KGpgChangeTrust() override;
+	explicit KGpgChangeTrust(QObject *parent, const QString &keyid, const gpgme_validity_t trust);
+	~KGpgChangeTrust() override = default;
 
 	void setTrust(const gpgme_validity_t trust);
 
